import { LazyResult } from 'postcss';
import { RawSourceMap } from 'source-map';
import { Result } from 'postcss';
import { SourceLocation } from '@vue/compiler-core';

export declare function compileStyle(options: StyleCompileOptions): StyleCompileResults;

export declare function compileStyleAsync(options: StyleCompileOptions): Promise<StyleCompileResults>;

export declare function compileTemplate(): void;

export declare function parse(source: string, { needMap, filename, sourceRoot, pad }?: SFCParseOptions): SFCDescriptor;

export declare interface SFCBlock {
    type: string;
    content: string;
    attrs: Record<string, string | true>;
    loc: SourceLocation;
    map?: RawSourceMap;
    lang?: string;
    src?: string;
}

export declare interface SFCDescriptor {
    filename: string;
    template: SFCTemplateBlock | null;
    script: SFCScriptBlock | null;
    styles: SFCStyleBlock[];
    customBlocks: SFCBlock[];
}

export declare interface SFCParseOptions {
    needMap?: boolean;
    filename?: string;
    sourceRoot?: string;
    pad?: boolean | 'line' | 'space';
}

export declare interface SFCScriptBlock extends SFCBlock {
    type: 'script';
}

export declare interface SFCStyleBlock extends SFCBlock {
    type: 'style';
    scoped?: boolean;
    module?: string | boolean;
}

export declare interface SFCTemplateBlock extends SFCBlock {
    type: 'template';
    functional?: boolean;
}

export declare interface StyleCompileOptions {
    source: string;
    filename: string;
    id: string;
    map?: object;
    scoped?: boolean;
    trim?: boolean;
    preprocessLang?: string;
    preprocessOptions?: any;
    postcssOptions?: any;
    postcssPlugins?: any[];
}

export declare interface StyleCompileResults {
    code: string;
    map: object | void;
    rawResult: LazyResult | Result | undefined;
    errors: string[];
}

export { }
